#include "lcd.h"
#include "usart.h"
#include <avr/io.h>
#include <util/delay.h>

typedef struct{

	int type;
	char x1, x2, y1, y2;
}Shape;

Shape shp;
char base_line[64];

void init_lcd(){

	for(int i = 0; i < 64; i++){
	
		base_line[i] = 0x40; // ultima linie de jos;
	}
}

int random_ShapeGen(){

	/**
	* 0 - box
	* 1 - line
	* 2 - T
	* 3 - L
	* 4 - L Rev
	* 5 - S
	* 6 - S rev
	*/

	return rand() % 7;
}

int shapes_landing(){ // verifica daca piesa a ajuns la baza constructiei
		
	char x = shp.x2;
	for(int i = (int)shp.y1; i < (int)shp.y2; i++){
			
		if(x == base_line[i] - 1)
			return 1;
	}
	
	return 0;
}

void draw_Obj(int type){

	switch(type){
	
		case 0: // Box
			draw_Box(0x00, 0x07, 0x1C, 0x23);
			shp.x1 = 0x00; shp.x2 = 0x07; shp.y1 = 0x1C; shp.y2 = 0x23;
			shp.type = 0;
			break;
		
		case 1: // Line
			draw_Box(0x00, 0x0F, 0x1E, 0x21);
			shp.x1 = 0x00; shp.x2 = 0x0F; shp.y1 = 0x1E; shp.y2 = 0x21;
			shp.type = 1;
			break;
			
		case 2: // T upside down
			draw_Box(0x00, 0x03, 0x1E, 0x21);
			draw_Box(0x04, 0x07, 0x1A, 0x1D);
			draw_Box(0x04, 0x07, 0x1E, 0x21);
			draw_Box(0x04, 0x07, 0x22, 0x25);
			shp.x1 = 0x00; shp.x2 = 0x07; shp.y1 = 0x1A; shp.y2 = 0x25;
			type = 2;
			break;
			
		case 3: // L
			draw_Box(0x00, 0x0F, 0x1E, 0x21);
			draw_Box(0x0C, 0x0F, 0x22, 0x25);
			shp.x1 = 0x00; shp.x2 = 0x0F; shp.y1 = 0x1E; shp.y2 = 0x25;
			shp.type = 3;
			break;
		
		case 4: // L reversed
			draw_Box(0x00, 0x0F, 0x1E, 0x21);
			draw_Box(0x0C, 0x0F, 0x1A, 0x1D);
			shp.x1 = 0x00; shp.x2 = 0x0F; shp.y1 = 0x1A; shp.y2 = 0x21;
			shp.type = 4;
			break;
		
		default:
			break;
	}
}

void clear_LCD(){

	uput_char(0x7C); // | - beginning of a command
	uput_char(0x00); // 0x00 - clear LCD Screed
}

void set_Baud(char x){

	uput_char(0x7C); // |
	uput_char(0x07); // CTRL g
	uput_char(x); // x e {1,2,3,4,5,6}
}

void set_Pixel(char x, char y){

	uput_char(0x7C); // |
	uput_char(0x10); // CTRL p
	uput_char(x);
	uput_char(y);
	uput_char(0x01);
}

void reset_Pixel(char x, char y){

	uput_char(0x7C); // |
	uput_char(0x10); // CTRL p
	uput_char(x);
	uput_char(y);
	uput_char(0x00);
}

void draw_Line(char x1, char x2, char y1, char y2){

	uput_char(0x7C); // |
	uput_char(0x0C); // CTRL l
	uput_char(x1);
	uput_char(y1);
	uput_char(x2);
	uput_char(y2);
	uput_char(0x01);
}

void erase_Line(char x1, char x2, char y1, char y2){

	uput_char(0x7C); // |
	uput_char(0x0C); // CTRL l
	uput_char(x1);
	uput_char(y1);
	uput_char(x2);
	uput_char(y2);
	uput_char(0x00);
}

void draw_Box(char x1, char x2, char y1, char y2){

	uput_char(0x7C); // |
	uput_char(0x0F); // CTRL o
	uput_char(x1);
	uput_char(y1);
	uput_char(x2);
	uput_char(y2);
	uput_char(0x01);
}

void erase_Box(char x1, char x2, char y1, char y2){

	uput_char(0x7C); // |
	uput_char(0x0F); // CTRL o
	uput_char(x1);
	uput_char(y1);
	uput_char(x2);
	uput_char(y2);
	uput_char(0x00);
}

void erase_Block(char x1, char y1, char x2, char y2){

	uput_char(0x7C); // |
	uput_char(0x05); // CTRL e
	uput_char(x1);
	uput_char(y1);
	uput_char(x2);
	uput_char(y2);
}